<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>DirectoryMenu</name>
    <message>
        <location filename="../directorymenu.cpp" line="125"/>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <location filename="../directorymenu.cpp" line="129"/>
        <source>Open in terminal</source>
        <translation>Megnyitás terminálban</translation>
    </message>
</context>
<context>
    <name>DirectoryMenuConfiguration</name>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="14"/>
        <source>Directory Menu Settings</source>
        <translation>Könyvtármenü beállítás</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Megjelenés</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="26"/>
        <source>Base directory:</source>
        <translation>Alapkönyvtár:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="39"/>
        <source>BaseDirectoryName</source>
        <translation>Alapkönyvtárnév</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="46"/>
        <source>Icon:</source>
        <translation>Ikon:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="66"/>
        <source>Terminal</source>
        <translation>Terminál</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="73"/>
        <location filename="../directorymenuconfiguration.cpp" line="112"/>
        <source>Choose Default Terminal</source>
        <translation>Alapértelmezett terminál kiválasztása</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="96"/>
        <source>Choose Base Directory</source>
        <translation>Alapkönyvtár kiválasztása</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="126"/>
        <source>Choose Icon</source>
        <translation>Ikon kiválasztása</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="126"/>
        <source>Icons (*.png *.xpm *.jpg)</source>
        <translation>Ikonok (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="135"/>
        <source>Directory Menu</source>
        <translation>Könyvtármenü</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="135"/>
        <source>An error occurred while loading the icon.</source>
        <translation>Hiba történt az ikon betöltése közben.</translation>
    </message>
</context>
</TS>
